# -*- coding:utf-8 -*-

eventLogString = {}

eventLogString["en"] = {
    'STR_EVENT_LOG_SOFTWARE_ID': "System Software ID",
    'STR_EVENT_LOG_TYPE': {
        0: "All Events",
        1: "System Event Records",
        2: "OEM Event Records",
        3: "BIOS Generated Events",
        4: "SMI Handler Events",
        5: "System Management Software Events",
        6: "System Software - OEM Events",
        7: "Remote Console software Events",
        8: "Terminal Mode Remote Console software Events"
    },
    'STR_EVENT_LOG_ASSERT': "Asserted",
    'STR_EVENT_LOG_DEASSERT': "Deasserted",
    'STR_EVENT_LOG_INVALID_OFFSET': "Invalid Offset for this SensorType"
}