# -*- coding:utf-8 -*-

sensorSpecificEventStr_EN = {}

sensorSpecificEventStr_EN[0] = "reserved"
sensorSpecificEventStr_EN[1] = "Temperature"
sensorSpecificEventStr_EN[2] = "Voltage"
sensorSpecificEventStr_EN[3] = "Current"
sensorSpecificEventStr_EN[4] = "Fan"

sensorSpecificEventStr_EN[5] = {}
sensorSpecificEventStr_EN[5][0] = "General Chassis Intrusion"
sensorSpecificEventStr_EN[5][1] = "Drive Bay Intrusion"
sensorSpecificEventStr_EN[5][2] = "I/O Card Area Intrusion"
sensorSpecificEventStr_EN[5][3] = "Processor Area Intrusion"
sensorSpecificEventStr_EN[5][4] = "LAN Leash Lost (System unplugged from LAN)"
sensorSpecificEventStr_EN[5][5] = "Unauthorized Dock/Undock"
sensorSpecificEventStr_EN[5][6] = "Fan Area Intrusion"

sensorSpecificEventStr_EN[6] = {}
sensorSpecificEventStr_EN[6][0] = "Secure Mode Violation Attempt"
sensorSpecificEventStr_EN[6][1] = "Pre-boot Password Violation - user password"
sensorSpecificEventStr_EN[6][2] = "Pre-boot Password Violation Attempt - setup password"
sensorSpecificEventStr_EN[6][3] = "Pre-boot Password Violation - network boot password"
sensorSpecificEventStr_EN[6][4] = "Other Pre-boot Password Violation"
sensorSpecificEventStr_EN[6][5] = "Out-of-Band Access Password Violation"

sensorSpecificEventStr_EN[7] = {}
sensorSpecificEventStr_EN[7][0] = "IERR"
sensorSpecificEventStr_EN[7][1] = "Thermal Trip"
sensorSpecificEventStr_EN[7][2] = "FRB1/BIST Failure"
sensorSpecificEventStr_EN[7][3] = "FRB2/Hang in POST Faliure"
sensorSpecificEventStr_EN[7][4] = "FRB3/Processor Startup/Initialization Failure"
sensorSpecificEventStr_EN[7][5] = "Configuration Error (DMI)"
sensorSpecificEventStr_EN[7][6] = "SM BIOS 'Uncorrectable CPU-complex Error"
sensorSpecificEventStr_EN[7][7] = "Processor Presence Detected"
sensorSpecificEventStr_EN[7][8] = "Processor Disabled"
sensorSpecificEventStr_EN[7][9] = "Terminator Presence Detected"
sensorSpecificEventStr_EN[7][10] = "Processor Automatically Throttled"
sensorSpecificEventStr_EN[7][11] = "Machine Check Exception"
sensorSpecificEventStr_EN[7][12] = "Correctable Machine Check Error"

sensorSpecificEventStr_EN[8] = {}
sensorSpecificEventStr_EN[8][0] = "Presence Detected"
sensorSpecificEventStr_EN[8][1] = "Power Supply Failure Detected"
sensorSpecificEventStr_EN[8][2] = "Predictive Failure Asserted"
sensorSpecificEventStr_EN[8][3] = "Power Supply Input Lost (AC/DC)"
sensorSpecificEventStr_EN[8][4] = "Power Supply Input Lost or Out of Range"
sensorSpecificEventStr_EN[8][5] = "Power Supply Input Out of Range, but Present"
sensorSpecificEventStr_EN[8][6] = "Configuration Error"
sensorSpecificEventStr_EN[8][7] = "PSU Power Supply Lost"
sensorSpecificEventStr_EN[8][8] = "PCH Power Supply Lost"

sensorSpecificEventStr_EN[8][9] = "PSU B0 Module Power Supply Lost"
sensorSpecificEventStr_EN[8][10] = "PSU B2 Module Power Supply Lost"
sensorSpecificEventStr_EN[8][11] = "PSU B4 Module Power Supply Lost"
sensorSpecificEventStr_EN[8][12] = "PSU B6 Module Power Supply Lost"

sensorSpecificEventStr_EN[9] = {}
sensorSpecificEventStr_EN[9][0] = "Power Off / Power Down"
sensorSpecificEventStr_EN[9][1] = "Power Cycle"
sensorSpecificEventStr_EN[9][2] = "240VA Power Down"
sensorSpecificEventStr_EN[9][3] = "Interlock Power Down"
sensorSpecificEventStr_EN[9][4] = "AC Lost / Power input lost"
sensorSpecificEventStr_EN[9][5] = "Soft Power Control Failure"
sensorSpecificEventStr_EN[9][6] = "Power Unit Failure Detected"
sensorSpecificEventStr_EN[9][7] = "Predictive Failure"

sensorSpecificEventStr_EN[12] = {}
sensorSpecificEventStr_EN[12][0] = "Correctable ECC"
sensorSpecificEventStr_EN[12][1] = "Uncorrectable ECC"
sensorSpecificEventStr_EN[12][2] = "Parity"
sensorSpecificEventStr_EN[12][3] = "Memory Scrub Failure"
sensorSpecificEventStr_EN[12][4] = "Memory Device Disabled"
sensorSpecificEventStr_EN[12][5] = "Correctable ECC Logging Limit Reached"
sensorSpecificEventStr_EN[12][6] = "Presence Detected"
sensorSpecificEventStr_EN[12][7] = "Configuration Error"
sensorSpecificEventStr_EN[12][8] = "Spare"
sensorSpecificEventStr_EN[12][9] = "Memory Automatically Throttled"
sensorSpecificEventStr_EN[12][10] = "Critical Overtemperature"

sensorSpecificEventStr_EN[13] = {}
sensorSpecificEventStr_EN[13][0] = "Drive Presence"
sensorSpecificEventStr_EN[13][1] = "Drive Fault"
sensorSpecificEventStr_EN[13][2] = "Predictive Failure"
sensorSpecificEventStr_EN[13][3] = "Hot Spare"
sensorSpecificEventStr_EN[13][4] = "Consistency Check / Parity Check in progress"
sensorSpecificEventStr_EN[13][5] = "In Critical Array"
sensorSpecificEventStr_EN[13][6] = "In Failed Array"
sensorSpecificEventStr_EN[13][7] = "Rebuild/Remap in progress"
sensorSpecificEventStr_EN[13][8] = "Rebuild/Remap Aborted"

sensorSpecificEventStr_EN[15] = {}
sensorSpecificEventStr_EN[15][0] = "Error"
sensorSpecificEventStr_EN[15][1] = "Hang"
sensorSpecificEventStr_EN[15][2] = "Progress"

sensorSpecificEventStr_EN[16] = {}
sensorSpecificEventStr_EN[16][0] = "Correctable Memory Error Logging Disabled"
sensorSpecificEventStr_EN[16][1] = "Event 'Type' Logging Disabled"
sensorSpecificEventStr_EN[16][2] = "Log Area Reset/Cleared"
sensorSpecificEventStr_EN[16][3] = "All Event Logging Disabled"
sensorSpecificEventStr_EN[16][4] = "SEL Full"
sensorSpecificEventStr_EN[16][5] = "SEL Almost Full"
sensorSpecificEventStr_EN[16][6] = "Correctable Machine Check Error Logging Disabled"

sensorSpecificEventStr_EN[17] = {}
sensorSpecificEventStr_EN[17][0] = "BIOS Watchdog Reset"
sensorSpecificEventStr_EN[17][1] = "OS Watchdog Reset"
sensorSpecificEventStr_EN[17][2] = "OS Watchdog Shutdown"
sensorSpecificEventStr_EN[17][3] = "OS Watchdog Power Down"
sensorSpecificEventStr_EN[17][4] = "OS Watchdog Power Cycle"
sensorSpecificEventStr_EN[17][5] = "OS Watchdog NMI"
sensorSpecificEventStr_EN[17][6] = "OS Watchdog Expired"
sensorSpecificEventStr_EN[17][7] = "OS Watchdog Pre-timeout Interrupt, non-NMI"

sensorSpecificEventStr_EN[18] = {}
sensorSpecificEventStr_EN[18][0] = "System Reconfigured"
sensorSpecificEventStr_EN[18][1] = "OEM System Boot Event"
sensorSpecificEventStr_EN[18][2] = "Undetermined System Hardware Failure"
sensorSpecificEventStr_EN[18][3] = "Entry Added to Auxiliary Log"
sensorSpecificEventStr_EN[18][4] = "PEF Action"
sensorSpecificEventStr_EN[18][5] = "SEL Time Update(OS)"

sensorSpecificEventStr_EN[19] = {}
sensorSpecificEventStr_EN[19][0] = "Front Panel NMI"
sensorSpecificEventStr_EN[19][1] = "Bus Timeout"
sensorSpecificEventStr_EN[19][2] = "I/O Channel Check NMI"
sensorSpecificEventStr_EN[19][3] = "Software NMI"
sensorSpecificEventStr_EN[19][4] = "PCI PERR"
sensorSpecificEventStr_EN[19][5] = "PCI SERR"
sensorSpecificEventStr_EN[19][6] = "EISA Fail Safe Timeout"
sensorSpecificEventStr_EN[19][7] = "Bus Correctable Error"
sensorSpecificEventStr_EN[19][8] = "Bus Uncorrectable Error"
sensorSpecificEventStr_EN[19][9] = "Fatal NMI"
sensorSpecificEventStr_EN[19][10] = "Bus Fatal Error"
sensorSpecificEventStr_EN[19][11] = "Bus Degraded"

sensorSpecificEventStr_EN[20] = {}
sensorSpecificEventStr_EN[20][0] = "Power Button Pressed"
sensorSpecificEventStr_EN[20][1] = "Sleep Button Pressed"
sensorSpecificEventStr_EN[20][2] = "Reset Button Pressed"
sensorSpecificEventStr_EN[20][3] = "FRU Latch Open"
sensorSpecificEventStr_EN[20][4] = "FRU Service Request Button"

sensorSpecificEventStr_EN[25] = {}
sensorSpecificEventStr_EN[25][0] = "Soft Power Control Failure"
sensorSpecificEventStr_EN[25][1] = "Thermal Trip"

sensorSpecificEventStr_EN[27] = {}
sensorSpecificEventStr_EN[27][0] = "Cable/Interconnect is connected"
sensorSpecificEventStr_EN[27][1] = "Configuration Error"
sensorSpecificEventStr_EN[27][2] = "Cable/Interconnect is not connected"

sensorSpecificEventStr_EN[29] = {}
sensorSpecificEventStr_EN[29][0] = "Initiated By Power Up"
sensorSpecificEventStr_EN[29][1] = "Initiated By Hard Reset"
sensorSpecificEventStr_EN[29][2] = "Initiated By Warm Reset"
sensorSpecificEventStr_EN[29][3] = "User Requested PXE Boot"
sensorSpecificEventStr_EN[29][4] = "Automatic Boot to Diagnostic"
sensorSpecificEventStr_EN[29][5] = "OS / run-time software initiated hard reset"
sensorSpecificEventStr_EN[29][6] = "OS / run-time software initiated warm reset"
sensorSpecificEventStr_EN[29][7] = "System Restart"

sensorSpecificEventStr_EN[30] = {}
sensorSpecificEventStr_EN[30][0] = "No Bootable Media"
sensorSpecificEventStr_EN[30][1] = "Non-Bootable Diskette Left in Drive"
sensorSpecificEventStr_EN[30][2] = "PXE Server Not Found"
sensorSpecificEventStr_EN[30][3] = "Invalid Boot Sector"
sensorSpecificEventStr_EN[30][4] = "Timeout Waiting For User Selection of Boot Source"

sensorSpecificEventStr_EN[31] = {}
sensorSpecificEventStr_EN[31][0] = "A: Boot Completed"
sensorSpecificEventStr_EN[31][1] = "C: Boot Completed"
sensorSpecificEventStr_EN[31][2] = "PXE Boot Completed"
sensorSpecificEventStr_EN[31][3] = "Diagnostic Boot Completed"
sensorSpecificEventStr_EN[31][4] = "CD-ROM Boot Completed"
sensorSpecificEventStr_EN[31][5] = "ROM Boot Completed"
sensorSpecificEventStr_EN[31][6] = "Boot Completed - Boot Device Not Specified"
sensorSpecificEventStr_EN[31][7] = "Base OS/Hypervisor Installation started"
sensorSpecificEventStr_EN[31][8] = "Base OS/Hypervisor Installation completed"
sensorSpecificEventStr_EN[31][9] = "Base OS/Hypervisor Installation aborted"
sensorSpecificEventStr_EN[31][10] = "Base OS/Hypervisor Installation failed"

sensorSpecificEventStr_EN[32] = {}
sensorSpecificEventStr_EN[32][0] = "Critical stop during OS load / initialization"
sensorSpecificEventStr_EN[32][1] = "Run-time Critical Stop"
sensorSpecificEventStr_EN[32][2] = "OS Graceful Stop"
sensorSpecificEventStr_EN[32][3] = "OS Graceful Shutdown"
sensorSpecificEventStr_EN[32][4] = "Soft Shutdown initiated by PEF"
sensorSpecificEventStr_EN[32][5] = "Agent Not Responding"

sensorSpecificEventStr_EN[33] = {}
sensorSpecificEventStr_EN[33][0] = "Fault Status Asserted"
sensorSpecificEventStr_EN[33][1] = "Identify Status Asserted"
sensorSpecificEventStr_EN[33][2] = "Slot/Connector Device Installed/Attached"
sensorSpecificEventStr_EN[33][3] = "Slot/Connector Ready For Device Installation"
sensorSpecificEventStr_EN[33][4] = "Slot/Connector Ready For Device Removal"
sensorSpecificEventStr_EN[33][5] = "Slot Power is Off"
sensorSpecificEventStr_EN[33][6] = "Slot/Connector Device Removal Request"
sensorSpecificEventStr_EN[33][7] = "Interlock Asserted"
sensorSpecificEventStr_EN[33][8] = "Slot is Disabled"
sensorSpecificEventStr_EN[33][9] = "Slot Holds Spare Device"

sensorSpecificEventStr_EN[34] = {}
sensorSpecificEventStr_EN[34][0] = "S0/G0 'Working"
sensorSpecificEventStr_EN[34][1] = "S1 'Sleeping With System HW & Processor Context Maintained'"
sensorSpecificEventStr_EN[34][2] = "S2 'Sleeping, Processor Context Lost'"
sensorSpecificEventStr_EN[34][3] = "S3 'Sleeping, Processor & HW Context Lost, Memory Retained'"
sensorSpecificEventStr_EN[34][4] = "S4 'Non-Volatile Sleep/Suspend To Disk'"
sensorSpecificEventStr_EN[34][5] = "S5/G2 'Soft Off'"
sensorSpecificEventStr_EN[34][6] = "S4/S5 Soft Off, Particular S4/S5 State Cannot Be Determined"
sensorSpecificEventStr_EN[34][7] = "G3 / Mechanical Off"
sensorSpecificEventStr_EN[34][8] = "Sleeping in S1, S2, or S3"
sensorSpecificEventStr_EN[34][9] = "G1 Sleeping"
sensorSpecificEventStr_EN[34][10] = "S5 Entered By Override"
sensorSpecificEventStr_EN[34][11] = "Legacy ON State"
sensorSpecificEventStr_EN[34][12] = "Legacy OFF State"
sensorSpecificEventStr_EN[34][13] = "Unknown"

sensorSpecificEventStr_EN[35] = {}
sensorSpecificEventStr_EN[35][0] = "Timer Expired"
sensorSpecificEventStr_EN[35][1] = "Hard Reset"
sensorSpecificEventStr_EN[35][2] = "Power Down"
sensorSpecificEventStr_EN[35][3] = "Power Cycle"
sensorSpecificEventStr_EN[35][4] = "Reserved"
sensorSpecificEventStr_EN[35][5] = "Reserved"
sensorSpecificEventStr_EN[35][6] = "Reserved"
sensorSpecificEventStr_EN[35][7] = "Reserved"
sensorSpecificEventStr_EN[35][8] = "Timer Interrupt"

sensorSpecificEventStr_EN[36] = {}
sensorSpecificEventStr_EN[36][0] = "Platform Generated Page"
sensorSpecificEventStr_EN[36][1] = "Platform Generated LAN Alert"
sensorSpecificEventStr_EN[36][2] = "Platform Event Trap Generated"
sensorSpecificEventStr_EN[36][3] = "Platform Generated SNMP Trap, OEM Format"

sensorSpecificEventStr_EN[37] = {}
sensorSpecificEventStr_EN[37][0] = "Entity Present"
sensorSpecificEventStr_EN[37][1] = "Entity Absent"
sensorSpecificEventStr_EN[37][2] = "Entity Disabled"

sensorSpecificEventStr_EN[39] = {}
sensorSpecificEventStr_EN[39][0] = "LAN Heartbeat Lost"
sensorSpecificEventStr_EN[39][1] = "LAN Heartbeat"

sensorSpecificEventStr_EN[40] = {}
sensorSpecificEventStr_EN[40][0] = "Sensor Access Degraded or Unavailable"
sensorSpecificEventStr_EN[40][1] = "Controller Access Degraded or Unavailable"
sensorSpecificEventStr_EN[40][2] = "Management Controller Off-line"
sensorSpecificEventStr_EN[40][3] = "Management Controller Unavailable"
sensorSpecificEventStr_EN[40][4] = "Sensor failure"
sensorSpecificEventStr_EN[40][5] = "FRU failure"

sensorSpecificEventStr_EN[41] = {}
sensorSpecificEventStr_EN[41][0] = "Battery Low"
sensorSpecificEventStr_EN[41][1] = "Battery Failed"
sensorSpecificEventStr_EN[41][2] = "Battery Presence Detected"

sensorSpecificEventStr_EN[42] = {}
sensorSpecificEventStr_EN[42][0] = "Session Activated"
sensorSpecificEventStr_EN[42][1] = "Session Deactivated"
sensorSpecificEventStr_EN[42][2] = "Invalid Username or Password"
sensorSpecificEventStr_EN[42][3] = "Invalid password disable"

sensorSpecificEventStr_EN[43] = {}
sensorSpecificEventStr_EN[43][0] = "Hardware Change Detected"
sensorSpecificEventStr_EN[43][1] = "Firmware / Software Change Detected"
sensorSpecificEventStr_EN[43][2] = "Hardware Incompatibility Detected"
sensorSpecificEventStr_EN[43][3] = "Firmware / Software Incompatibility Detected"
sensorSpecificEventStr_EN[43][4] = "Invalid or Unsupported Hardware Version"
sensorSpecificEventStr_EN[43][5] = "Invalid or Unsupported Firmware / Software Version"
sensorSpecificEventStr_EN[43][6] = "Hardware Change Detected was successful"
sensorSpecificEventStr_EN[43][7] = "Firmware / Software Change Detected was successful"

sensorSpecificEventStr_EN[44] = {}
sensorSpecificEventStr_EN[44][0] = "FRU Not Installed"
sensorSpecificEventStr_EN[44][1] = "FRU Inactive"
sensorSpecificEventStr_EN[44][2] = "FRU Activation Requested"
sensorSpecificEventStr_EN[44][3] = "FRU Activation In Progress"
sensorSpecificEventStr_EN[44][4] = "FRU Active"
sensorSpecificEventStr_EN[44][5] = "FRU Deactivation Requested"
sensorSpecificEventStr_EN[44][6] = "FRU Deactivation In Progress"
sensorSpecificEventStr_EN[44][7] = "FRU Communication Lost"

sensorSpecificEventStr_EN[194] = {}
sensorSpecificEventStr_EN[194][0] = "PMBus Power Module 0 undefined Error"
sensorSpecificEventStr_EN[194][1] = "PMBus Power Module 0 communicate, memory, controller Error"
sensorSpecificEventStr_EN[194][2] = "PMBus Power Module 0 temperature Error"
sensorSpecificEventStr_EN[194][3] = "PMBus Power Module 0 voltage or current input Error"
sensorSpecificEventStr_EN[194][4] = "PMBus Power Module 0 current output Error"
sensorSpecificEventStr_EN[194][5] = "PMBus Power Module 0 voltage output Error"
sensorSpecificEventStr_EN[194][6] = "PMBus Power Module 0 is off"
sensorSpecificEventStr_EN[194][7] = "PMBus Power Module 0 is busy"
sensorSpecificEventStr_EN[194][8] = "PMBus Power Module 0 unknown Error or Warning"
sensorSpecificEventStr_EN[194][9] = "PMBus Power Module 0 other Error"
sensorSpecificEventStr_EN[194][10] = "PMBus Power Module 0 fan Error"
sensorSpecificEventStr_EN[194][11] = "PMBus Power Module 0 power supply abnormal"
sensorSpecificEventStr_EN[194][12] = "PMBus Power Module 0 user defined Error"
sensorSpecificEventStr_EN[194][13] = "PMBus Power Module 0 voltage or current input Error"
sensorSpecificEventStr_EN[194][14] = "PMBus Power Module 0 current or Power output Error"
sensorSpecificEventStr_EN[194][15] = "PMBus Power Module 0 voltage output Error"

sensorSpecificEventStr_EN[194][16] = "PMBus Power Module 1 undefined Error"
sensorSpecificEventStr_EN[194][17] = "PMBus Power Module 1 communicate, memory, controller Error"
sensorSpecificEventStr_EN[194][18] = "PMBus Power Module 1 temperature Error"
sensorSpecificEventStr_EN[194][19] = "PMBus Power Module 1 voltage or current input Error"
sensorSpecificEventStr_EN[194][20] = "PMBus Power Module 1 current output Error"
sensorSpecificEventStr_EN[194][21] = "PMBus Power Module 1 voltage output Error"
sensorSpecificEventStr_EN[194][22] = "PMBus Power Module 1 is off"
sensorSpecificEventStr_EN[194][23] = "PMBus Power Module 1 is busy"
sensorSpecificEventStr_EN[194][24] = "PMBus Power Module 1 unknown Error or Warning"
sensorSpecificEventStr_EN[194][25] = "PMBus Power Module 1 other Error"
sensorSpecificEventStr_EN[194][26] = "PMBus Power Module 1 fan Error"
sensorSpecificEventStr_EN[194][27] = "PMBus Power Module 1 power supply abnormal"
sensorSpecificEventStr_EN[194][28] = "PMBus Power Module 1 user defined Error"
sensorSpecificEventStr_EN[194][29] = "PMBus Power Module 1 voltage or current input Error"
sensorSpecificEventStr_EN[194][30] = "PMBus Power Module 1 current or Power output Error"
sensorSpecificEventStr_EN[194][31] = "PMBus Power Module 1 voltage output Error"

sensorSpecificEventStr_EN[194][32] = "PMBus Power Module 2 undefined Error"
sensorSpecificEventStr_EN[194][33] = "PMBus Power Module 2 communicate, memory, controller Error"
sensorSpecificEventStr_EN[194][34] = "PMBus Power Module 2 temperature Error"
sensorSpecificEventStr_EN[194][35] = "PMBus Power Module 2 voltage or current input Error"
sensorSpecificEventStr_EN[194][36] = "PMBus Power Module 2 current output Error"
sensorSpecificEventStr_EN[194][37] = "PMBus Power Module 2 voltage output Error"
sensorSpecificEventStr_EN[194][38] = "PMBus Power Module 2 is off"
sensorSpecificEventStr_EN[194][39] = "PMBus Power Module 2 is busy"
sensorSpecificEventStr_EN[194][40] = "PMBus Power Module 2 unknown Error or Warning"
sensorSpecificEventStr_EN[194][41] = "PMBus Power Module 2 other Error"
sensorSpecificEventStr_EN[194][42] = "PMBus Power Module 2 fan Error"
sensorSpecificEventStr_EN[194][43] = "PMBus Power Module 2 power supply abnormal"
sensorSpecificEventStr_EN[194][44] = "PMBus Power Module 2 user defined Error"
sensorSpecificEventStr_EN[194][45] = "PMBus Power Module 2 voltage or current input Error"
sensorSpecificEventStr_EN[194][46] = "PMBus Power Module 2 current or Power output Error"
sensorSpecificEventStr_EN[194][47] = "PMBus Power Module 2 voltage output Error"

sensorSpecificEventStr_EN[194][48] = "PMBus Power Module 3 undefined Error"
sensorSpecificEventStr_EN[194][49] = "PMBus Power Module 3 communicate, memory, controller Error"
sensorSpecificEventStr_EN[194][50] = "PMBus Power Module 3 temperature Error"
sensorSpecificEventStr_EN[194][51] = "PMBus Power Module 3 voltage or current input Error"
sensorSpecificEventStr_EN[194][52] = "PMBus Power Module 3 current output Error"
sensorSpecificEventStr_EN[194][53] = "PMBus Power Module 3 voltage output Error"
sensorSpecificEventStr_EN[194][54] = "PMBus Power Module 3 is off"
sensorSpecificEventStr_EN[194][55] = "PMBus Power Module 3 is busy"
sensorSpecificEventStr_EN[194][56] = "PMBus Power Module 3 unknown Error or Warning"
sensorSpecificEventStr_EN[194][57] = "PMBus Power Module 3 other Error"
sensorSpecificEventStr_EN[194][58] = "PMBus Power Module 3 fan Error"
sensorSpecificEventStr_EN[194][59] = "PMBus Power Module 3 power supply abnormal"
sensorSpecificEventStr_EN[194][60] = "PMBus Power Module 3 user defined Error"
sensorSpecificEventStr_EN[194][61] = "PMBus Power Module 3 voltage or current input Error"
sensorSpecificEventStr_EN[194][62] = "PMBus Power Module 3 current or Power output Error"
sensorSpecificEventStr_EN[194][63] = "PMBus Power Module 3 voltage output Error"

sensorSpecificEventStr_EN[195] = {}
sensorSpecificEventStr_EN[195][0] = "CPU0 Bus and interconnect Error"
sensorSpecificEventStr_EN[195][1] = "CPU0 L3 Tag Error"
sensorSpecificEventStr_EN[195][2] = "CPU0 Internal Error"

sensorSpecificEventStr_EN[195][16] = "CPU1 Bus and interconnect Error"
sensorSpecificEventStr_EN[195][17] = "CPU1 L3 Tag Error"
sensorSpecificEventStr_EN[195][18] = "CPU1 Internal Error"

sensorSpecificEventStr_EN[195][32] = "CPU2 Bus and interconnect Error"
sensorSpecificEventStr_EN[195][33] = "CPU2 L3 Tag Error"
sensorSpecificEventStr_EN[195][34] = "CPU2 Internal Error"

sensorSpecificEventStr_EN[195][48] = "CPU3 Bus and interconnect Error"
sensorSpecificEventStr_EN[195][49] = "CPU3 L3 Tag Error"
sensorSpecificEventStr_EN[195][50] = "CPU3 Internal Error"

sensorSpecificEventStr_EN[196] = {}
sensorSpecificEventStr_EN[196][0] = "CPU0 Channel0 Dimm0 memory Error"
sensorSpecificEventStr_EN[196][1] = "CPU0 Channel0 Dimm1 memory Error"
sensorSpecificEventStr_EN[196][2] = "CPU0 Channel0 Dimm2 memory Error"

sensorSpecificEventStr_EN[196][4] = "CPU0 Channel1 Dimm0 memory Error"
sensorSpecificEventStr_EN[196][5] = "CPU0 Channel1 Dimm1 memory Error"
sensorSpecificEventStr_EN[196][6] = "CPU0 Channel1 Dimm2 memory Error"

sensorSpecificEventStr_EN[196][8] = "CPU0 Channel2 Dimm0 memory Error"
sensorSpecificEventStr_EN[196][9] = "CPU0 Channel2 Dimm1 memory Error"
sensorSpecificEventStr_EN[196][10] = "CPU0 Channel2 Dimm2 memory Error"

sensorSpecificEventStr_EN[196][12] = "CPU0 Channel3 Dimm0 memory Error"
sensorSpecificEventStr_EN[196][13] = "CPU0 Channel3 Dimm1 memory Error"
sensorSpecificEventStr_EN[196][14] = "CPU0 Channel3 Dimm2 memory Error"

sensorSpecificEventStr_EN[196][16] = "CPU1 Channel0 Dimm0 memory Error"
sensorSpecificEventStr_EN[196][17] = "CPU1 Channel0 Dimm1 memory Error"
sensorSpecificEventStr_EN[196][18] = "CPU1 Channel0 Dimm2 memory Error"

sensorSpecificEventStr_EN[196][20] = "CPU1 Channel1 Dimm0 memory Error"
sensorSpecificEventStr_EN[196][21] = "CPU1 Channel1 Dimm1 memory Error"
sensorSpecificEventStr_EN[196][22] = "CPU1 Channel1 Dimm2 memory Error"

sensorSpecificEventStr_EN[196][24] = "CPU1 Channel2 Dimm0 memory Error"
sensorSpecificEventStr_EN[196][25] = "CPU1 Channel2 Dimm1 memory Error"
sensorSpecificEventStr_EN[196][26] = "CPU1 Channel2 Dimm2 memory Error"

sensorSpecificEventStr_EN[196][28] = "CPU1 Channel3 Dimm0 memory Error"
sensorSpecificEventStr_EN[196][29] = "CPU1 Channel3 Dimm1 memory Error"
sensorSpecificEventStr_EN[196][30] = "CPU1 Channel3 Dimm2 memory Error"

sensorSpecificEventStr_EN[196][32] = "CPU2 Channel0 Dimm0 memory Error"
sensorSpecificEventStr_EN[196][33] = "CPU2 Channel0 Dimm1 memory Error"
sensorSpecificEventStr_EN[196][34] = "CPU2 Channel0 Dimm2 memory Error"

sensorSpecificEventStr_EN[196][36] = "CPU2 Channel1 Dimm0 memory Error"
sensorSpecificEventStr_EN[196][37] = "CPU2 Channel1 Dimm1 memory Error"
sensorSpecificEventStr_EN[196][38] = "CPU2 Channel1 Dimm2 memory Error"

sensorSpecificEventStr_EN[196][40] = "CPU2 Channel2 Dimm0 memory Error"
sensorSpecificEventStr_EN[196][41] = "CPU2 Channel2 Dimm1 memory Error"
sensorSpecificEventStr_EN[196][42] = "CPU2 Channel2 Dimm2 memory Error"

sensorSpecificEventStr_EN[196][44] = "CPU2 Channel3 Dimm0 memory Error"
sensorSpecificEventStr_EN[196][45] = "CPU2 Channel3 Dimm1 memory Error"
sensorSpecificEventStr_EN[196][46] = "CPU2 Channel3 Dimm2 memory Error"

sensorSpecificEventStr_EN[196][48] = "CPU3 Channel0 Dimm0 memory Error"
sensorSpecificEventStr_EN[196][49] = "CPU3 Channel0 Dimm1 memory Error"
sensorSpecificEventStr_EN[196][50] = "CPU3 Channel0 Dimm2 memory Error"

sensorSpecificEventStr_EN[196][52] = "CPU3 Channel1 Dimm0 memory Error"
sensorSpecificEventStr_EN[196][53] = "CPU3 Channel1 Dimm1 memory Error"
sensorSpecificEventStr_EN[196][54] = "CPU3 Channel1 Dimm2 memory Error"

sensorSpecificEventStr_EN[196][56] = "CPU3 Channel2 Dimm0 memory Error"
sensorSpecificEventStr_EN[196][57] = "CPU3 Channel2 Dimm1 memory Error"
sensorSpecificEventStr_EN[196][58] = "CPU3 Channel2 Dimm2 memory Error"

sensorSpecificEventStr_EN[196][60] = "CPU3 Channel3 Dimm0 memory Error"
sensorSpecificEventStr_EN[196][61] = "CPU3 Channel3 Dimm1 memory Error"
sensorSpecificEventStr_EN[196][62] = "CPU3 Channel3 Dimm2 memory Error"

sensorSpecificEventStr_EN[197] = {}
sensorSpecificEventStr_EN[197][0] = "PMBus Power Module 1 OV Error"
sensorSpecificEventStr_EN[197][16] = "PMBus Power Module 2 OV Error"

sensorSpecificEventStr_EN[199] = {}
sensorSpecificEventStr_EN[199][0] = "Disk 1  Error"
sensorSpecificEventStr_EN[199][16] = "Disk 2 Error"
sensorSpecificEventStr_EN[199][32] = "Disk 3 Error"
sensorSpecificEventStr_EN[199][48] = "Disk 4 Error"
sensorSpecificEventStr_EN[199][64] = "Disk 5 Error"
sensorSpecificEventStr_EN[199][80] = "Disk 6 Error"

sensorSpecificEventStr_EN[200] = {}
sensorSpecificEventStr_EN[200][0] = "Redundant Test OK"
sensorSpecificEventStr_EN[200][1] = "Redundant Test Not Ready, Input Mode Error"
sensorSpecificEventStr_EN[200][2] = "Redundant Test Fail, Status Word Error"
sensorSpecificEventStr_EN[200][3] = "Input Was Set To AC Forcedly"
sensorSpecificEventStr_EN[200][4] = "Input Was Set To DC Forcedly"
sensorSpecificEventStr_EN[200][5] = "Redundant Test Fail,Input Mode Forcedly Set Fail"
sensorSpecificEventStr_EN[200][6] = "Redundant Test Fail, Cold Redundant Mode Error"
sensorSpecificEventStr_EN[200][7] = "Redundant Test Fail, Send CMD Failed"

sensorSpecificEventStr_EN[201] = {}
sensorSpecificEventStr_EN[201][0] = "BIOS Setup Options Cleared in BMC"
sensorSpecificEventStr_EN[201][1] = "BIOS Setup Options Setted in BMC"

sensorSpecificEventStr_CN = {}
sensorSpecificEventStr_CN[0] = "保留"
sensorSpecificEventStr_CN[1] = "温度"
sensorSpecificEventStr_CN[2] = "电压"
sensorSpecificEventStr_CN[3] = "电流"
sensorSpecificEventStr_CN[4] = "风扇"
sensorSpecificEventStr_CN[5] = {}
sensorSpecificEventStr_CN[5][0] = "一般机箱入侵"
sensorSpecificEventStr_CN[5][1] = "驱动器托架入侵"
sensorSpecificEventStr_CN[5][2] = "I/O卡区入侵"
sensorSpecificEventStr_CN[5][3] = "处理器区域入侵"
sensorSpecificEventStr_CN[5][4] = "局域网丢失（系统从局域网拔除）"
sensorSpecificEventStr_CN[5][5] = "未受权的插入/移除"
sensorSpecificEventStr_CN[5][6] = "风扇区域入侵"
sensorSpecificEventStr_CN[6] = {}
sensorSpecificEventStr_CN[6][0] = "安全模式违反企图"
sensorSpecificEventStr_CN[6][1] = "违反前开机密码-用户密码"
sensorSpecificEventStr_CN[6][2] = "违反前开机密码-设置密码"
sensorSpecificEventStr_CN[6][3] = "违反前开机密码-网络引导密码"
sensorSpecificEventStr_CN[6][4] = "其他违反前开机密码"
sensorSpecificEventStr_CN[6][5] = "违反带外访问密码"
sensorSpecificEventStr_CN[7] = {}
sensorSpecificEventStr_CN[7][0] = "IERR"
sensorSpecificEventStr_CN[7][1] = "过热保护"
sensorSpecificEventStr_CN[7][2] = "FRB1/BIST故障"
sensorSpecificEventStr_CN[7][3] = "FRB2/开机阶段宕机故障"
sensorSpecificEventStr_CN[7][4] = "FRB3/处理器初始化故障"
sensorSpecificEventStr_CN[7][5] = "配置故障（DMI）"
sensorSpecificEventStr_CN[7][6] = "SMBIOS无法纠正的CPU复杂故障"
sensorSpecificEventStr_CN[7][7] = "检测到处理器的存在"
sensorSpecificEventStr_CN[7][8] = "处理器禁用"
sensorSpecificEventStr_CN[7][9] = "检测到终端的存在"
sensorSpecificEventStr_CN[7][10] = "处理器自动节流"
sensorSpecificEventStr_CN[7][11] = "MCE错误"
sensorSpecificEventStr_CN[7][12] = "可恢复的MCE错误"

sensorSpecificEventStr_CN[8] = {}
sensorSpecificEventStr_CN[8][0] = "检测到存在"
sensorSpecificEventStr_CN[8][1] = "检测到电源故障"
sensorSpecificEventStr_CN[8][2] = "预测性故障生效"
sensorSpecificEventStr_CN[8][3] = "电源输入丢失（交流/直流）"
sensorSpecificEventStr_CN[8][4] = "电源输入丢失或者超出范围"
sensorSpecificEventStr_CN[8][5] = "电源输入超出范围，但是存在。"
sensorSpecificEventStr_CN[8][6] = "配置故障"
sensorSpecificEventStr_CN[8][7] = "PSU电源输入丢失"
sensorSpecificEventStr_CN[8][8] = "PCH电源输入丢失"
sensorSpecificEventStr_CN[8][9] = "PSU B0模块不存在"
sensorSpecificEventStr_CN[8][10] = "PSU B2模块不存在"
sensorSpecificEventStr_CN[8][11] = "PSU B4模块不存在"
sensorSpecificEventStr_CN[8][12] = "PSU B6模块不存在"
sensorSpecificEventStr_CN[9] = {}
sensorSpecificEventStr_CN[9][0] = "关机"
sensorSpecificEventStr_CN[9][1] = "循环开关机"
sensorSpecificEventStr_CN[9][2] = "240VA断电"
sensorSpecificEventStr_CN[9][3] = "连锁断电"
sensorSpecificEventStr_CN[9][4] = "交流丢失"
sensorSpecificEventStr_CN[9][5] = "软开关机控制失败"
sensorSpecificEventStr_CN[9][6] = "检测到电源单元故障"
sensorSpecificEventStr_CN[9][7] = "预测故障"
sensorSpecificEventStr_CN[12] = {}
sensorSpecificEventStr_CN[12][0] = "可更正的ECC故障"
sensorSpecificEventStr_CN[12][1] = "不可更正的ECC故障"
sensorSpecificEventStr_CN[12][2] = "奇偶校验"
sensorSpecificEventStr_CN[12][3] = "内存擦写故障"
sensorSpecificEventStr_CN[12][4] = "内存设备禁用"
sensorSpecificEventStr_CN[12][5] = "可更正的ECC日志记录到达限制"
sensorSpecificEventStr_CN[12][6] = "检测到存在"
sensorSpecificEventStr_CN[12][7] = "配置故障"
sensorSpecificEventStr_CN[12][8] = "空"
sensorSpecificEventStr_CN[12][9] = "节流"
sensorSpecificEventStr_CN[12][15] = "自定义故障"
sensorSpecificEventStr_CN[13] = {}
sensorSpecificEventStr_CN[13][0] = "硬盘存在"
sensorSpecificEventStr_CN[13][1] = "硬盘错误"
sensorSpecificEventStr_CN[13][2] = "故障预测"
sensorSpecificEventStr_CN[13][3] = "热备用"
sensorSpecificEventStr_CN[13][4] = "一致性检查/奇偶检查处理"
sensorSpecificEventStr_CN[13][5] = "在关键组"
sensorSpecificEventStr_CN[13][6] = "在故障组"
sensorSpecificEventStr_CN[13][7] = "重建/映射处理中"
sensorSpecificEventStr_CN[13][8] = "重建/映射失败"
sensorSpecificEventStr_CN[15] = {}
sensorSpecificEventStr_CN[15][0] = "故障"
sensorSpecificEventStr_CN[15][1] = "宕机"
sensorSpecificEventStr_CN[15][2] = "处理"
sensorSpecificEventStr_CN[16] = {}
sensorSpecificEventStr_CN[16][0] = "可更正内存故障日志记录禁用"
sensorSpecificEventStr_CN[16][1] = "事件类型日志记录禁用"
sensorSpecificEventStr_CN[16][2] = "日志记录区域复位/清空"
sensorSpecificEventStr_CN[16][3] = "所有事件日志记录禁用"
sensorSpecificEventStr_CN[16][4] = "SEL满"
sensorSpecificEventStr_CN[16][5] = "SEL将近满"
sensorSpecificEventStr_CN[17] = {}
sensorSpecificEventStr_CN[17][0] = "BIOS看门狗复位"
sensorSpecificEventStr_CN[17][1] = "操作系统看门狗复位"
sensorSpecificEventStr_CN[17][2] = "操作系统看门狗关机"
sensorSpecificEventStr_CN[17][3] = "操作系统看门狗关机"
sensorSpecificEventStr_CN[17][4] = "操作系统看门狗循环开关机"
sensorSpecificEventStr_CN[17][5] = "操作系统看门狗NMI"
sensorSpecificEventStr_CN[17][6] = "操作系统看门狗计数完成"
sensorSpecificEventStr_CN[17][7] = "OS看门狗预超时中断，非NMI"
sensorSpecificEventStr_CN[18] = {}
sensorSpecificEventStr_CN[18][0] = "系统重配置"
sensorSpecificEventStr_CN[18][1] = "OEM系统启动事件"
sensorSpecificEventStr_CN[18][2] = "未定义的系统硬件故障"
sensorSpecificEventStr_CN[18][3] = "条目添加到辅助日志"
sensorSpecificEventStr_CN[18][4] = "PEF动作"
sensorSpecificEventStr_CN[18][5] = "SEL时钟同步(OS)"
sensorSpecificEventStr_CN[19] = {}
sensorSpecificEventStr_CN[19][0] = "前面板NMI"
sensorSpecificEventStr_CN[19][1] = "总线超时"
sensorSpecificEventStr_CN[19][2] = "I/O通道检测NMI"
sensorSpecificEventStr_CN[19][3] = "软件NMI"
sensorSpecificEventStr_CN[19][4] = "PCI PERR"
sensorSpecificEventStr_CN[19][5] = "PCI SERR"
sensorSpecificEventStr_CN[19][6] = "EISA安全超时失败"
sensorSpecificEventStr_CN[19][7] = "总线可更正故障"
sensorSpecificEventStr_CN[19][8] = "总线不可更正故障"
sensorSpecificEventStr_CN[19][9] = "严重的NMI"
sensorSpecificEventStr_CN[19][10] = "严重的总线故障"
sensorSpecificEventStr_CN[19][11] = "检测到严重的SMLINK0故障"
sensorSpecificEventStr_CN[19][12] = "检测到严重的SMLINK1故障"
sensorSpecificEventStr_CN[20] = {}
sensorSpecificEventStr_CN[20][0] = "开/关键按下"
sensorSpecificEventStr_CN[20][1] = "睡眠键按下"
sensorSpecificEventStr_CN[20][2] = "复位键按下 或者 系统重启动"
sensorSpecificEventStr_CN[20][3] = "FRU锁打开"
sensorSpecificEventStr_CN[20][4] = "FRU服务请求键"
sensorSpecificEventStr_CN[22] = {}
sensorSpecificEventStr_CN[22][0] = "检测到CPU故障"
sensorSpecificEventStr_CN[25] = {}
sensorSpecificEventStr_CN[25][0] = "软开关机控制失败"
sensorSpecificEventStr_CN[25][1] = "过热保护"
sensorSpecificEventStr_CN[27] = {}
sensorSpecificEventStr_CN[27][0] = "电缆/网络已连接"
sensorSpecificEventStr_CN[27][1] = "故障"
sensorSpecificEventStr_CN[27][2] = "未连接"
sensorSpecificEventStr_CN[29] = {}
sensorSpecificEventStr_CN[29][0] = "开始通电"
sensorSpecificEventStr_CN[29][1] = "开始硬件复位"
sensorSpecificEventStr_CN[29][2] = "开始热复位"
sensorSpecificEventStr_CN[29][3] = "用户请求PXE启动"
sensorSpecificEventStr_CN[29][4] = "自动引导到诊断"
sensorSpecificEventStr_CN[29][5] = "OS/运行时软件启动硬复位"
sensorSpecificEventStr_CN[29][6] = "OS/运行时软件启动热复位"
sensorSpecificEventStr_CN[29][7] = "系统重启动"
sensorSpecificEventStr_CN[30] = {}
sensorSpecificEventStr_CN[30][0] = "没有可引导介质"
sensorSpecificEventStr_CN[30][1] = "非引导软盘留在驱动器"
sensorSpecificEventStr_CN[30][2] = "未发现PXE服务器"
sensorSpecificEventStr_CN[30][3] = "无效的引导扇区"
sensorSpecificEventStr_CN[30][4] = "等待用户选择启动资源超时"
sensorSpecificEventStr_CN[31] = {}
sensorSpecificEventStr_CN[31][0] = "A:启动完成"
sensorSpecificEventStr_CN[31][1] = "C:启动完成"
sensorSpecificEventStr_CN[31][2] = "PXE启动完成"
sensorSpecificEventStr_CN[31][3] = "诊断引导完成"
sensorSpecificEventStr_CN[31][4] = "CD-ROM引导完成"
sensorSpecificEventStr_CN[31][5] = "ROM引导完成"
sensorSpecificEventStr_CN[31][6] = "引导完成-目标操作系统未知"
sensorSpecificEventStr_CN[31][7] = "基本OS/虚拟机开始安装"
sensorSpecificEventStr_CN[31][8] = "基本OS/虚拟机安装完成"
sensorSpecificEventStr_CN[31][9] = "基本OS/虚拟机安装中止"
sensorSpecificEventStr_CN[31][10] = "基本OS/虚拟机安装失败"
sensorSpecificEventStr_CN[32] = {}
sensorSpecificEventStr_CN[32][0] = "操作系统初始化过程中停止"
sensorSpecificEventStr_CN[32][1] = "运行时停止"
sensorSpecificEventStr_CN[32][2] = "OS正常停止"
sensorSpecificEventStr_CN[32][3] = "OS正常关机"
sensorSpecificEventStr_CN[32][4] = "由PEF触发的软关机"
sensorSpecificEventStr_CN[32][5] = "代理无响应"
sensorSpecificEventStr_CN[33] = {}
sensorSpecificEventStr_CN[33][0] = "故障状态生效"
sensorSpecificEventStr_CN[33][1] = "确定状态生效"
sensorSpecificEventStr_CN[33][2] = "槽/连接器设备已连接"
sensorSpecificEventStr_CN[33][3] = "槽/连接器准备安装"
sensorSpecificEventStr_CN[33][4] = "槽/连接器准备移除"
sensorSpecificEventStr_CN[33][5] = "插槽的电源是关闭"
sensorSpecificEventStr_CN[33][6] = "槽/连接器移除请求"
sensorSpecificEventStr_CN[33][7] = "连锁生效"
sensorSpecificEventStr_CN[33][8] = "槽禁用"
sensorSpecificEventStr_CN[33][9] = "槽可以容纳备用设备"
sensorSpecificEventStr_CN[34] = {}
sensorSpecificEventStr_CN[34][0] = "S0/G0 “运行中”"
sensorSpecificEventStr_CN[34][1] = "S1 “睡眠，系统硬件及处理器保留”"
sensorSpecificEventStr_CN[34][2] = "S2 “睡眠，处理器丢失”"
sensorSpecificEventStr_CN[34][3] = "S3 “睡眠，处理器和硬件丢失，内存保留”"
sensorSpecificEventStr_CN[34][4] = "S4 “睡眠/挂起”"
sensorSpecificEventStr_CN[34][5] = "S5/G2 “软关机”"
sensorSpecificEventStr_CN[34][6] = "S4/S5 “软关机，需要指出的是S4/S5状态不确定”"
sensorSpecificEventStr_CN[34][7] = "G3 “机械关机”"
sensorSpecificEventStr_CN[34][8] = "睡眠在S1, S2,或者S3"
sensorSpecificEventStr_CN[34][9] = "G1睡眠"
sensorSpecificEventStr_CN[34][10] = "进入到S5"
sensorSpecificEventStr_CN[34][11] = "停留在开机状态"
sensorSpecificEventStr_CN[34][12] = "停留在关机状态"
sensorSpecificEventStr_CN[34][13] = "未知"
sensorSpecificEventStr_CN[35] = {}
sensorSpecificEventStr_CN[35][0] = "时间到"
sensorSpecificEventStr_CN[35][1] = "硬件重启动"
sensorSpecificEventStr_CN[35][2] = "关机"
sensorSpecificEventStr_CN[35][3] = "循环开关机"
sensorSpecificEventStr_CN[35][4] = "保留"
sensorSpecificEventStr_CN[35][5] = "保留"
sensorSpecificEventStr_CN[35][6] = "保留"
sensorSpecificEventStr_CN[35][7] = "保留"
sensorSpecificEventStr_CN[35][8] = "时钟中断"
sensorSpecificEventStr_CN[36] = {}
sensorSpecificEventStr_CN[36][0] = "平台生成的页面"
sensorSpecificEventStr_CN[36][1] = "平台生成的LAN告警"
sensorSpecificEventStr_CN[36][2] = "生成平台事件Trap"
sensorSpecificEventStr_CN[36][3] = "生成平台SNMP Trap，OEM格式"
sensorSpecificEventStr_CN[37] = {}
sensorSpecificEventStr_CN[37][0] = "实体存在"
sensorSpecificEventStr_CN[37][1] = "实体缺席"
sensorSpecificEventStr_CN[37][2] = "实体禁用"
sensorSpecificEventStr_CN[39] = {}
sensorSpecificEventStr_CN[39][0] = "局域网心跳丢失"
sensorSpecificEventStr_CN[39][1] = "局域网心跳"
sensorSpecificEventStr_CN[40] = {}
sensorSpecificEventStr_CN[40][0] = "传感器无法访问或不可用"
sensorSpecificEventStr_CN[40][1] = "控制器无法访问或不可用"
sensorSpecificEventStr_CN[40][2] = "管理控制器下线"
sensorSpecificEventStr_CN[40][3] = "管理控制器不可用"
sensorSpecificEventStr_CN[40][4] = "传感器故障"
sensorSpecificEventStr_CN[40][5] = "FRU故障"
sensorSpecificEventStr_CN[41] = {}
sensorSpecificEventStr_CN[41][0] = "电池电量低"
sensorSpecificEventStr_CN[41][1] = "电池故障"
sensorSpecificEventStr_CN[41][2] = "检测到电池的存在"
sensorSpecificEventStr_CN[42] = {}
sensorSpecificEventStr_CN[42][0] = "会话激活"
sensorSpecificEventStr_CN[42][1] = "会话未激活"
sensorSpecificEventStr_CN[43] = {}
sensorSpecificEventStr_CN[43][0] = "检测到硬件变更"
sensorSpecificEventStr_CN[43][1] = "检测到固件/软件变更"
sensorSpecificEventStr_CN[43][2] = "检测到硬件不兼容"
sensorSpecificEventStr_CN[43][3] = "检测到固件/软件不兼容"
sensorSpecificEventStr_CN[43][4] = "无效或者不支持的硬件版本"
sensorSpecificEventStr_CN[43][5] = "无效或者不支持的固件/软件版本"
sensorSpecificEventStr_CN[43][6] = "检测到硬件的变化是成功的"
sensorSpecificEventStr_CN[43][7] = "检测到固件/软件的变化是成功的"
sensorSpecificEventStr_CN[44] = {}
sensorSpecificEventStr_CN[44][0] = "FRU未安装"
sensorSpecificEventStr_CN[44][1] = "FRU无效"
sensorSpecificEventStr_CN[44][2] = "要求的FRU启用"
sensorSpecificEventStr_CN[44][3] = "FRU可用"
sensorSpecificEventStr_CN[44][4] = "FRU活动"
sensorSpecificEventStr_CN[44][5] = "要求的FRU停用"
sensorSpecificEventStr_CN[44][6] = "FRU可用"
sensorSpecificEventStr_CN[44][7] = "FRU通讯丢失"
sensorSpecificEventStr_CN[194] = {}
sensorSpecificEventStr_CN[194][0] = "PMBus电源模块0出现未定义错误"
sensorSpecificEventStr_CN[194][1] = "PMBus电源模块0通讯，内存或者控制器故障"
sensorSpecificEventStr_CN[194][2] = "PMBus电源模块0温度故障"
sensorSpecificEventStr_CN[194][3] = "PMBus电源模块0输入电压或电流错误"
sensorSpecificEventStr_CN[194][4] = "PMBus电源模块0输出电流故障"
sensorSpecificEventStr_CN[194][5] = "PMBus电源模块0输出电压故障"
sensorSpecificEventStr_CN[194][6] = "PMBus电源模块0不在线"
sensorSpecificEventStr_CN[194][7] = "PMBus电源模块0正在忙"
sensorSpecificEventStr_CN[194][8] = "PMBus电源模块0未知的故障或告警"
sensorSpecificEventStr_CN[194][9] = "PMBus电源模块0其他故障"
sensorSpecificEventStr_CN[194][10] = "PMBus电源模块0风扇故障"
sensorSpecificEventStr_CN[194][11] = "PMBus电源模块0电源供电异常"
sensorSpecificEventStr_CN[194][12] = "PMBus电源模块0用户自定义故障"
sensorSpecificEventStr_CN[194][13] = "PMBus电源模块0输入电压或电流故障"
sensorSpecificEventStr_CN[194][14] = "PMBus电源模块0输出功率或电流故障"
sensorSpecificEventStr_CN[194][15] = "PMBus电源模块0输出电压故障"
sensorSpecificEventStr_CN[194][16] = "PMBus电源模块1出现未定义故障"
sensorSpecificEventStr_CN[194][17] = "PMBus电源模块1通讯，内存或者控制器故障"
sensorSpecificEventStr_CN[194][18] = "PMBus电源模块1温度故障"
sensorSpecificEventStr_CN[194][19] = "PMBus电源模块1输入电压或电流错误"
sensorSpecificEventStr_CN[194][20] = "PMBus电源模块1输出电流故障"
sensorSpecificEventStr_CN[194][21] = "PMBus电源模块1输出电压故障"
sensorSpecificEventStr_CN[194][22] = "PMBus电源模块1不在线"
sensorSpecificEventStr_CN[194][23] = "PMBus电源模块1正在忙"
sensorSpecificEventStr_CN[194][24] = "PMBus电源模块1未知的故障或告警"
sensorSpecificEventStr_CN[194][25] = "PMBus电源模块1其他故障"
sensorSpecificEventStr_CN[194][26] = "PMBus电源模块1风扇故障"
sensorSpecificEventStr_CN[194][27] = "PMBus电源模块1电源供电异常"
sensorSpecificEventStr_CN[194][28] = "PMBus电源模块1用户自定义故障"
sensorSpecificEventStr_CN[194][29] = "PMBus电源模块1输入电压或电流故障"
sensorSpecificEventStr_CN[194][30] = "PMBus电源模块1输出功率或电流故障"
sensorSpecificEventStr_CN[194][31] = "PMBus电源模块1输出电压故障"
sensorSpecificEventStr_CN[194][32] = "PMBus电源模块2出现未定义故障"
sensorSpecificEventStr_CN[194][33] = "PMBus电源模块2通讯，内存或者控制器故障"
sensorSpecificEventStr_CN[194][34] = "PMBus电源模块2温度故障"
sensorSpecificEventStr_CN[194][35] = "PMBus电源模块2输入电压或电流错误"
sensorSpecificEventStr_CN[194][36] = "PMBus电源模块2输出电流故障"
sensorSpecificEventStr_CN[194][37] = "PMBus电源模块2输出电压故障"
sensorSpecificEventStr_CN[194][38] = "PMBus电源模块2不在线"
sensorSpecificEventStr_CN[194][39] = "PMBus电源模块2正在忙"
sensorSpecificEventStr_CN[194][40] = "PMBus电源模块2未知的故障或告警"
sensorSpecificEventStr_CN[194][41] = "PMBus电源模块2其他故障"
sensorSpecificEventStr_CN[194][42] = "PMBus电源模块2风扇故障"
sensorSpecificEventStr_CN[194][43] = "PMBus电源模块2电源供电异常"
sensorSpecificEventStr_CN[194][44] = "PMBus电源模块2用户自定义故障"
sensorSpecificEventStr_CN[194][45] = "PMBus电源模块2输入电压或电流故障"
sensorSpecificEventStr_CN[194][46] = "PMBus电源模块2输出功率或电流故障"
sensorSpecificEventStr_CN[194][47] = "PMBus电源模块2输出电压故障"
sensorSpecificEventStr_CN[194][48] = "PMBus电源模块3出现未定义故障"
sensorSpecificEventStr_CN[194][49] = "PMBus电源模块3通讯，内存或者控制器故障"
sensorSpecificEventStr_CN[194][50] = "PMBus电源模块3温度故障"
sensorSpecificEventStr_CN[194][51] = "PMBus电源模块3输入电压或电流错误"
sensorSpecificEventStr_CN[194][52] = "PMBus电源模块3输出电流故障"
sensorSpecificEventStr_CN[194][53] = "PMBus电源模块3输出电压故障"
sensorSpecificEventStr_CN[194][54] = "PMBus电源模块3不在线"
sensorSpecificEventStr_CN[194][55] = "PMBus电源模块3正在忙"
sensorSpecificEventStr_CN[194][56] = "PMBus电源模块3未知的故障或告警"
sensorSpecificEventStr_CN[194][57] = "PMBus电源模块3其他故障"
sensorSpecificEventStr_CN[194][58] = "PMBus电源模块3风扇故障"
sensorSpecificEventStr_CN[194][59] = "PMBus电源模块3电源供电异常"
sensorSpecificEventStr_CN[194][60] = "PMBus电源模块3用户自定义故障"
sensorSpecificEventStr_CN[194][61] = "PMBus电源模块3输入电压或电流故障"
sensorSpecificEventStr_CN[194][62] = "PMBus电源模块3输出功率或电流故障"
sensorSpecificEventStr_CN[194][63] = "PMBus电源模块3输出电压故障"
sensorSpecificEventStr_CN[195] = {}
sensorSpecificEventStr_CN[195][0] = "CPU0发生Bus和Interconnect故障"
sensorSpecificEventStr_CN[195][1] = "CPU0发生L3 Tag故障"
sensorSpecificEventStr_CN[195][2] = "CPU0发生内部故障"
sensorSpecificEventStr_CN[195][16] = "CPU1发生Bus和Interconnect故障"
sensorSpecificEventStr_CN[195][17] = "CPU1发生L3 Tag故障"
sensorSpecificEventStr_CN[195][18] = "CPU1发生内部故障"
sensorSpecificEventStr_CN[195][32] = "CPU2发生Bus和Interconnect故障"
sensorSpecificEventStr_CN[195][33] = "CPU2发生L3 Tag故障"
sensorSpecificEventStr_CN[195][34] = "CPU2发生内部故障"
sensorSpecificEventStr_CN[195][48] = "CPU3发生Bus和Interconnect故障"
sensorSpecificEventStr_CN[195][49] = "CPU3发生L3 Tag故障"
sensorSpecificEventStr_CN[195][50] = "CPU3发生内部故障"
sensorSpecificEventStr_CN[196] = {}
sensorSpecificEventStr_CN[196][0] = "CPU0,Channel0,Dimm0发生内存故障"
sensorSpecificEventStr_CN[196][1] = "CPU0,Channel0,Dimm1发生内存故障"
sensorSpecificEventStr_CN[196][2] = "CPU0,Channel0,Dimm2发生内存故障"
sensorSpecificEventStr_CN[196][4] = "CPU0,Channel1,Dimm0发生内存故障"
sensorSpecificEventStr_CN[196][5] = "CPU0,Channel1,Dimm1发生内存故障"
sensorSpecificEventStr_CN[196][6] = "CPU0,Channel1,Dimm2发生内存故障"
sensorSpecificEventStr_CN[196][8] = "CPU0,Channel2,Dimm0发生内存故障"
sensorSpecificEventStr_CN[196][9] = "CPU0,Channel2,Dimm1发生内存故障"
sensorSpecificEventStr_CN[196][10] = "CPU0,Channel2,Dimm2发生内存故障"
sensorSpecificEventStr_CN[196][12] = "CPU0,Channel3,Dimm0发生内存故障"
sensorSpecificEventStr_CN[196][13] = "CPU0,Channel3,Dimm1发生内存故障"
sensorSpecificEventStr_CN[196][14] = "CPU0,Channel3,Dimm2发生内存故障"
sensorSpecificEventStr_CN[196][16] = "CPU1,Channel0,Dimm0发生内存故障"
sensorSpecificEventStr_CN[196][17] = "CPU1,Channel0,Dimm1发生内存故障"
sensorSpecificEventStr_CN[196][18] = "CPU1,Channel0,Dimm2发生内存故障"
sensorSpecificEventStr_CN[196][20] = "CPU1,Channel1,Dimm0发生内存故障"
sensorSpecificEventStr_CN[196][21] = "CPU1,Channel1,Dimm1发生内存故障"
sensorSpecificEventStr_CN[196][22] = "CPU1,Channel1,Dimm2发生内存故障"
sensorSpecificEventStr_CN[196][24] = "CPU1,Channel2,Dimm0发生内存故障"
sensorSpecificEventStr_CN[196][25] = "CPU1,Channel2,Dimm1发生内存故障"
sensorSpecificEventStr_CN[196][26] = "CPU1,Channel2,Dimm2发生内存故障"
sensorSpecificEventStr_CN[196][28] = "CPU1,Channel3,Dimm0发生内存故障"
sensorSpecificEventStr_CN[196][29] = "CPU1,Channel3,Dimm1发生内存故障"
sensorSpecificEventStr_CN[196][30] = "CPU1,Channel3,Dimm2发生内存故障"
sensorSpecificEventStr_CN[196][32] = "CPU2,Channel0,Dimm0发生内存故障"
sensorSpecificEventStr_CN[196][33] = "CPU2,Channel0,Dimm1发生内存故障"
sensorSpecificEventStr_CN[196][34] = "CPU2,Channel0,Dimm2发生内存故障"
sensorSpecificEventStr_CN[196][36] = "CPU2,Channel1,Dimm0发生内存故障"
sensorSpecificEventStr_CN[196][37] = "CPU2,Channel1,Dimm1发生内存故障"
sensorSpecificEventStr_CN[196][38] = "CPU2,Channel1,Dimm2发生内存故障"
sensorSpecificEventStr_CN[196][40] = "CPU2,Channel2,Dimm0发生内存故障"
sensorSpecificEventStr_CN[196][41] = "CPU2,Channel2,Dimm1发生内存故障"
sensorSpecificEventStr_CN[196][42] = "CPU2,Channel2,Dimm2发生内存故障"
sensorSpecificEventStr_CN[196][44] = "CPU2,Channel3,Dimm0发生内存故障"
sensorSpecificEventStr_CN[196][45] = "CPU2,Channel3,Dimm1发生内存故障"
sensorSpecificEventStr_CN[196][46] = "CPU2,Channel3,Dimm2发生内存故障"
sensorSpecificEventStr_CN[196][48] = "CPU3,Channel0,Dimm0发生内存故障"
sensorSpecificEventStr_CN[196][49] = "CPU3,Channel0,Dimm1发生内存故障"
sensorSpecificEventStr_CN[196][50] = "CPU3,Channel0,Dimm2发生内存故障"
sensorSpecificEventStr_CN[196][52] = "CPU3,Channel1,Dimm0发生内存故障"
sensorSpecificEventStr_CN[196][53] = "CPU3,Channel1,Dimm1发生内存故障"
sensorSpecificEventStr_CN[196][54] = "CPU3,Channel1,Dimm2发生内存故障"
sensorSpecificEventStr_CN[196][56] = "CPU3,Channel2,Dimm0发生内存故障"
sensorSpecificEventStr_CN[196][57] = "CPU3,Channel2,Dimm1发生内存故障"
sensorSpecificEventStr_CN[196][58] = "CPU3,Channel2,Dimm2发生内存故障"
sensorSpecificEventStr_CN[196][60] = "CPU3,Channel3,Dimm0发生内存故障"
sensorSpecificEventStr_CN[196][61] = "CPU3,Channel3,Dimm1发生内存故障"
sensorSpecificEventStr_CN[196][62] = "CPU3,Channel3,Dimm2发生内存故障"
sensorSpecificEventStr_CN[197] = {}
sensorSpecificEventStr_CN[197][0] = "PMBus电源模块1电压过载故障"
sensorSpecificEventStr_CN[197][16] = "PMBus电源模块2电压过载故障"

sensorSpecificEventStr_CN[199] = {}
sensorSpecificEventStr_CN[199][0] = "Disk 1  故障"
sensorSpecificEventStr_CN[199][16] = "Disk 2 故障"
sensorSpecificEventStr_CN[199][32] = "Disk 3 故障"
sensorSpecificEventStr_CN[199][48] = "Disk 4 故障"
sensorSpecificEventStr_CN[199][64] = "Disk 5 故障"
sensorSpecificEventStr_CN[199][80] = "Disk 6 故障"

sensorSpecificEventStr_CN[200] = {}
sensorSpecificEventStr_CN[200][0] = "电源冗余测试通过"
sensorSpecificEventStr_CN[200][1] = "电源冗余测试未就绪，输入模式错误"
sensorSpecificEventStr_CN[200][2] = "电源冗余测试失败，状态字异常"
sensorSpecificEventStr_CN[200][3] = "AC电源被设置成输入"
sensorSpecificEventStr_CN[200][4] = "DC电源被设置成输入"
sensorSpecificEventStr_CN[200][5] = "电源冗余测试失败，无法设置电源冗余状态"
sensorSpecificEventStr_CN[200][6] = "电源冗余测试失败，电源当前冗余状态错误"
sensorSpecificEventStr_CN[200][7] = "电源冗余测试失败，发送PMbus命令失败"

sensorSpecificEventStr_CN[201] = {}
sensorSpecificEventStr_CN[201][0] = "BMC中的BIOS配置参数被清空"
sensorSpecificEventStr_CN[201][1] = "BMC中的BIOS配置参数被设置"

sensorSpecificEventStr = {}
sensorSpecificEventStr["en"] = sensorSpecificEventStr_EN
sensorSpecificEventStr["cn"] = sensorSpecificEventStr_CN
